Learn R Programming

iNZightRegression (version 1.3.5)

iNZightRegression-package: iNZightRegression: Tools for Exploring Regression Models with 'iNZight'

Description

Provides a suite of functions to use with regression models, including summaries, residual plots, and factor comparisons. Used as part of the Model Fitting module of 'iNZight', a graphical user interface providing easy exploration and visualisation of data for students of statistics, available in both desktop and online versions.

Arguments

Author

Maintainer: Tom Elliott tom.elliott@auckland.ac.nz (ORCID)

Authors:

  • Simon Potter

  • David Banks

Other contributors:

  • Danny Chang [contributor]

See Also